@@ -50,6 +50,7 @@ import androidx.core.content.ContextCompat;
 
 // 本样例展示在线一句话语音识别/翻译使用方法
 // Android SDK 详细说明：
+// Websocket API 详细说明：https://help.aliyun.com/zh/model-studio/sentence-websocket-api
 public class DashGummySpeechRecognizerActivity extends Activity implements INativeNuiCallback, AdapterView.OnItemSelectedListener {
     private static final String TAG = "GummySR";
 
@@ -374,17 +375,18 @@ public class DashGummySpeechRecognizerActivity extends Activity implements INati
             // DNS解析的超时时间设置(单位ms)，默认5000
             //nls_config.put("dns_timeout", 500);
 
-
-            /*若文档中不包含某些参数，但是此功能支持这个参数，可以用如下万能接口设置参数*/
-//            JSONObject extend_config = new JSONObject();
-//            JSONObject vocab = new JSONObject();
-//            vocab.put("热词1", 2);
-//            vocab.put("热词2", 2);
-//            extend_config.put("vocabulary", vocab);
-//            nls_config.put("extend_config", extend_config);
+            // 设置文档中不存在的参数, key为custom_params, value以json string的形式设置参数
+            // 如下示例传入{parameters:{"custom_param_flag":true},"user111":"111"}表示在payload下添加参数
+            // payload.user111 : 111
+            // payload.parameters.custom_param_flag : true
+//            JSONObject custom_params = new JSONObject();
+//            JSONObject param = new JSONObject();
+//            custom_params.put("user111", "111");
+//            param.put("custom_param_flag", true);
+//            custom_params.put("parameters", param);
+//            nls_config.put("extend_config", custom_params);
 
             JSONObject parameters = new JSONObject();
-
             parameters.put("nls_config", nls_config);
             parameters.put("service_type", Constants.kServiceTypeASR); // 必填
 
@@ -486,7 +488,7 @@ public class DashGummySpeechRecognizerActivity extends Activity implements INati
             object.put("debug_path", debugpath);
 
             //过滤SDK内部日志通过回调送回到用户层
-            object.put("log_track_level", String.valueOf(Constants.LogLevel.toInt(Constants.LogLevel.LOG_LEVEL_INFO)));
+            object.put("log_track_level", String.valueOf(Constants.LogLevel.toInt(Constants.LogLevel.LOG_LEVEL_NONE)));
 
             // FullMix = 0   // 选用此模式开启本地功能并需要进行鉴权注册
             // FullCloud = 1
