@@ -47,7 +47,7 @@ import java.util.Map;
 import java.util.concurrent.LinkedBlockingQueue;
 
 // 本样例展示百炼在线Paraformer实时语音识别使用方法
-// Android SDK 详细说明：
+// Android SDK 详细说明：https://help.aliyun.com/zh/model-studio/android-sdk-for-paraformer-real-time-service
 // Paraformer实时语音识别WebSocket API: https://help.aliyun.com/zh/model-studio/websocket-for-paraformer-real-time-service
 public class DashParaformerSpeechTranscriberActivity extends Activity implements INativeNuiCallback, AdapterView.OnItemSelectedListener {
     private static final String TAG = "ParaformerST";
@@ -301,7 +301,7 @@ public class DashParaformerSpeechTranscriberActivity extends Activity implements
 //            resource.put("resource_id", "111");
 //            resource.put("resource_type", "asr_phrase");
 //            resources.add(resource);
-//            nls_config.put("resources", resources.toString());
+//            nls_config.put("resources", resources);
 
             // 当需要与服务端保持长连接时，可通过该开关进行控制
 //            nls_config.put("heartbeat", true);
@@ -315,7 +315,7 @@ public class DashParaformerSpeechTranscriberActivity extends Activity implements
 //            JSONArray language_hints_array = new JSONArray();
 //            language_hints_array.add("zh");
 //            language_hints_array.add("en");
-//            nls_config.put("language_hints", language_hints_array.toString());
+//            nls_config.put("language_hints", language_hints_array);
 
             if (mVadSwitch.isChecked()) {
                 // 设置开启VAD（Voice Activity Detection，语音活动检测）断句，默认关闭。
@@ -332,10 +332,16 @@ public class DashParaformerSpeechTranscriberActivity extends Activity implements
             // 设置是否在识别结果中自动添加标点。
 //            nls_config.put("punctuation_prediction_enabled", true);
 
-            /*若文档中不包含某些参数，但是此功能支持这个参数，可以用如下万能接口设置参数*/
-//            JSONObject extend_config = new JSONObject();
-//            extend_config.put("custom_test", true);
-//            nls_config.put("extend_config", extend_config);
+            // 设置文档中不存在的参数, key为custom_params, value以json string的形式设置参数
+            // 如下示例传入{parameters:{"custom_param_flag":true},"user111":"111"}表示在payload下添加参数
+            // payload.user111 : 111
+            // payload.parameters.custom_param_flag : true
+//            JSONObject custom_params = new JSONObject();
+//            JSONObject param = new JSONObject();
+//            custom_params.put("user111", "111");
+//            param.put("custom_param_flag", true);
+//            custom_params.put("parameters", param);
+//            nls_config.put("extend_config", custom_params);
 
             JSONObject tmp = new JSONObject();
             tmp.put("nls_config", nls_config);
@@ -439,7 +445,7 @@ public class DashParaformerSpeechTranscriberActivity extends Activity implements
             object.put("max_log_file_size", 50 * 1024 * 1024);
 
             //过滤SDK内部日志通过回调送回到用户层
-            object.put("log_track_level", String.valueOf(Constants.LogLevel.toInt(Constants.LogLevel.LOG_LEVEL_INFO)));
+            object.put("log_track_level", String.valueOf(Constants.LogLevel.toInt(Constants.LogLevel.LOG_LEVEL_NONE)));
 
             // FullMix = 0   // 选用此模式开启本地功能并需要进行鉴权注册
             // FullCloud = 1
